Installation
============

Install PyHarmX using the following command:

.. code-block::

   pip install pyharmx

PyHarmX has minimal dependencies, requiring only PyTorch and NumPy.

If you're interested in contributing or want to use PyHarmX in developer/editable mode with test dependencies, install it as follows:

.. code-block::

   pip install -e pyharmx[test]

To run the tests, simply execute:

.. code-block::

   pytest <path-to-pyharmx>

Explore
============

Check out the `examples <https://github.com/ivanZanardi/pyharmx/tree/main/examples>`_ provided in the repository to see PyHarmX in action.

License
============

PyHarmX is distributed under the `MIT License <https://github.com/ivanZanardi/pyharmx/blob/main/LICENSE>`_. Feel free to use, modify, and contribute to this project within the terms of the license.